@@ -150,7 +150,7 @@ namespace Menu {
 		},
 		{
 			"╦ ╦╔═╗╦  ╔═╗",
-			"╠═╣║╣ ║  ╠═╝",
+			"╠═╣╠╣ ║  ╠═╝",
 			"╩ ╩╚═╝╩═╝╩  "
 		},
 		{
@@ -711,6 +711,17 @@ namespace Menu {
 				"",
 				"Will otherwise automatically choose the NIC",
 				"with the highest total download since boot."},
+		    {"base_10_bitrate",
+			    "Base 10 bitrate",
+			    "",
+			    "True:  Use SI prefixes for bitrates",
+			    "       (1000Kbps = 1Mbps)",
+			    "False: Use binary prefixes for bitrates",
+			    "       (1024Kibps = 1Mibps)",
+			    "Auto:  Use the General -> Base 10 Sizes",
+			    "       setting for bitrates",
+			    "",
+			    "True, False, or Auto",},
 		},
 		{
 			{"proc_left",
@@ -787,7 +798,7 @@ namespace Menu {
 	};
 
 	msgBox::msgBox() {}
-	msgBox::msgBox(int width, int boxtype, vector<string> content, string title)
+	msgBox::msgBox(int width, int boxtype, const vector<string>& content, string title)
 	: width(width), boxtype(boxtype) {
 		auto tty_mode = Config::getB("tty_mode");
 		auto rounded = Config::getB("rounded_corners");
@@ -867,8 +878,8 @@ namespace Menu {
 		button_left.shrink_to_fit();
 		button_right.clear();
 		button_right.shrink_to_fit();
-		if (mouse_mappings.contains("button1")) mouse_mappings.erase("button1");
-		if (mouse_mappings.contains("button2")) mouse_mappings.erase("button2");
+		mouse_mappings.erase("button1");
+		mouse_mappings.erase("button2");
 	}
 
 	enum menuReturnCodes {
@@ -878,7 +889,7 @@ namespace Menu {
 		Switch
 	};
 
-	int signalChoose(const string& key) {
+	static int signalChoose(const string& key) {
 		auto s_pid = (Config::getB("show_detailed") and Config::getI("selected_pid") == 0 ? Config::getI("detailed_pid") : Config::getI("selected_pid"));
 		static int x{};
 		static int y{};
@@ -986,12 +997,12 @@ namespace Menu {
 		return (redraw ? Changed : retval);
 	}
 
-	int sizeError(const string& key) {
+	static int sizeError(const string& key) {
 		if (redraw) {
-			vector<string> cont_vec;
-			cont_vec.push_back(Fx::b + Theme::g("used")[100] + "Error:" + Theme::c("main_fg") + Fx::ub);
-			cont_vec.push_back("Terminal size to small to" + Fx::reset);
-			cont_vec.push_back("display menu or box!" + Fx::reset);
+			vector<string> cont_vec {
+				Fx::b + Theme::g("used")[100] + "Error:" + Theme::c("main_fg") + Fx::ub,
+				"Terminal size to small to" + Fx::reset,
+				"display menu or box!" + Fx::reset };
 
 			messageBox = Menu::msgBox{45, 0, cont_vec, "error"};
 			Global::overlay = messageBox();
@@ -1008,7 +1019,7 @@ namespace Menu {
 		return NoChange;
 	}
 
-	int signalSend(const string& key) {
+	static int signalSend(const string& key) {
 		auto s_pid = (Config::getB("show_detailed") and Config::getI("selected_pid") == 0 ? Config::getI("detailed_pid") : Config::getI("selected_pid"));
 		if (s_pid == 0) return Closed;
 		if (redraw) {
@@ -1048,7 +1059,7 @@ namespace Menu {
 		return NoChange;
 	}
 
-	int signalReturn(const string& key) {
+	static int signalReturn(const string& key) {
 		if (redraw) {
 			vector<string> cont_vec;
 			cont_vec.push_back(Fx::b + Theme::g("used")[100] + "Failure:" + Theme::c("main_fg") + Fx::ub);
@@ -1080,7 +1091,7 @@ namespace Menu {
 		return NoChange;
 	}
 
-	int mainMenu(const string& key) {
+	static int mainMenu(const string& key) {
 		enum MenuItems { Options, Help, Quit };
 		static int y{};
 		static int selected{};
@@ -1159,8 +1170,8 @@ namespace Menu {
 		return (redraw ? Changed : retval);
 	}
 
-	int optionsMenu(const string& key) {
-		enum Predispositions { isBool, isInt, isString, is2D, isBrowseable, isEditable};
+static int optionsMenu(const string& key) {
+ 		enum Predispositions { isBool, isInt, isString, is2D, isBrowsable, isEditable};
 		static int y{};
 		static int x{};
 		static int height{};
@@ -1190,6 +1201,7 @@ namespace Menu {
 			{"cpu_graph_lower", std::cref(Cpu::available_fields)},
 			{"cpu_sensor", std::cref(Cpu::available_sensors)},
 			{"selected_battery", std::cref(Config::available_batteries)},
+	        {"base_10_bitrate", std::cref(Config::base_10_bitrate_values)},
 		#ifdef GPU_SUPPORT
 			{"show_gpu_info", std::cref(Config::show_gpu_values)},
 			{"graph_symbol_gpu", std::cref(Config::valid_graph_symbols_def)},
@@ -1314,10 +1326,12 @@ namespace Menu {
 		else if (pages > 1 and key == "page_down") {
 			if (++page >= pages) page = 0;
 			selected = 0;
+			last_sel = -1;
 		}
 		else if (pages > 1 and key == "page_up") {
 			if (--page < 0) page = pages - 1;
 			selected = 0;
+			last_sel = -1;
 		}
 		else if (key == "tab") {
 			if (++selected_cat >= (int)categories.size()) selected_cat = 0;
@@ -1327,8 +1341,12 @@ namespace Menu {
 			if (--selected_cat < 0) selected_cat = (int)categories.size() - 1;
 			page = selected = 0;
 		}
+#ifdef GPU_SUPPORT
 		else if (is_in(key, "1", "2", "3", "4", "5", "6") or key.starts_with("select_cat_")) {
-			selected_cat = key.back() - '0' - 1;
+#else
+		else if (is_in(key, "1", "2", "3", "4", "5") or key.starts_with("select_cat_")) {
+#endif
+		selected_cat = key.back() - '0' - 1;
 			page = selected = 0;
 		}
 		else if (is_in(key, "left", "right") or (vim_keys and is_in(key, "h", "l"))) {
@@ -1365,7 +1383,7 @@ namespace Menu {
 					recollect = true;
 				}
 			}
-			else if (selPred.test(isBrowseable)) {
+			else if (selPred.test(isBrowsable)) {
 				auto& optList = optionsList.at(option).get();
 				int i = v_index(optList, Config::getS(option));
 
@@ -1379,6 +1397,9 @@ namespace Menu {
 					Logger::set(optList.at(i));
 					Logger::info("Logger set to " + optList.at(i));
 				}
+				else if (option == "base_10_bitrate") {
+				    recollect = true;
+				}
 				else if (is_in(option, "proc_sorting", "cpu_sensor", "show_gpu_info") or option.starts_with("graph_symbol") or option.starts_with("cpu_graph_"))
 					screen_redraw = true;
 			}
@@ -1417,9 +1438,9 @@ namespace Menu {
 				if (not selPred.test(isString))
 					selPred.set(is2D);
 				else if (optionsList.contains(selOption)) {
-					selPred.set(isBrowseable);
+					selPred.set(isBrowsable);
 				}
-				if (not selPred.test(isBrowseable) and (selPred.test(isString) or selPred.test(isInt)))
+				if (not selPred.test(isBrowsable) and (selPred.test(isString) or selPred.test(isInt)))
 					selPred.set(isEditable);
 			}
 
@@ -1450,18 +1471,18 @@ namespace Menu {
 			auto cy = y+9;
 			for (int c = 0, i = max(0, item_height * page); c++ < item_height and i < (int)categories[selected_cat].size(); i++) {
 				const auto& option = categories[selected_cat][i][0];
-				const auto& value = (option == "color_theme" ? (string) fs::path(Config::getS("color_theme")).stem() : Config::getAsString(option));
+				const auto& value = (option == "color_theme" ? fs::path(Config::getS("color_theme")).stem().string() : Config::getAsString(option));
 
 				out += Mv::to(cy++, x + 1) + (c-1 == selected ? Theme::c("selected_bg") + Theme::c("selected_fg") : Theme::c("title"))
 					+ Fx::b + cjust(capitalize(s_replace(option, "_", " "))
-						+ (c-1 == selected and selPred.test(isBrowseable)
+						+ (c-1 == selected and selPred.test(isBrowsable)
 							? ' ' + to_string(v_index(optionsList.at(option).get(), (option == "color_theme" ? Config::getS("color_theme") : value)) + 1) + '/' + to_string(optionsList.at(option).get().size())
 							: ""), 29);
 				out	+= Mv::to(cy++, x + 1) + (c-1 == selected ? "" : Theme::c("main_fg")) + Fx::ub + "  "
 					+ (c-1 == selected and editing ? cjust(editor(24), 34, true) : cjust(value, 25, true)) + "  ";
 
 				if (c-1 == selected) {
-					if (not editing and (selPred.test(is2D) or selPred.test(isBrowseable))) {
+					if (not editing and (selPred.test(is2D) or selPred.test(isBrowsable))) {
 						out += Fx::b + Mv::to(cy-1, x+2) + Symbols::left + Mv::to(cy-1, x+28) + Symbols::right;
 						mouse_mappings["left"] = {cy-2, x, 2, 5};
 						mouse_mappings["right"] = {cy-2, x+25, 2, 5};
@@ -1511,7 +1532,7 @@ namespace Menu {
 		return (redraw ? Changed : retval);
 	}
 
-	int helpMenu(const string& key) {
+	static int helpMenu(const string& key) {
 		static int y{};
 		static int x{};
 		static int height{};
